adult_ml1_cat.RdUses a validated ML model that uses keywords in the domain name and suffix to predict probability that the domain hosts adult content. For more information see https://github.com/themains/keyword_porn
adult_ml1_cat(domains = NULL)data.frame with original list and content category of the domains
if (FALSE) { # \dontrun{
adult_ml1_cat("http://www.google.com")
} # }