get_stevenblack_data: Get Steven Black's Host List Data

View source: R/get_stevenblack_data.R

get_stevenblack_dataR Documentation

Get Steven Black's Host List Data

Description

Downloads the latest version of Steven Black's unified hosts file. The hosts file contains domains known for serving ads, malware, and tracking.

Usage

get_stevenblack_data(outdir = "./", variant = "base", overwrite = FALSE)

Arguments

outdir

Optional; folder to which you want to save the file; Default is current directory

variant

Optional; which variant to download. Options: "base", "porn", "social", "gambling", "all"

overwrite

Optional; default is FALSE. If TRUE, the file is overwritten.

References

https://github.com/StevenBlack/hosts

Examples

## Not run: 
get_stevenblack_data()
get_stevenblack_data(variant = "all")

## End(Not run)

rdomains documentation built on May 14, 2026, 9:07 a.m.