Returns category of content from multiple security vendors using the VirusTotal API v3. The function retrieves domain analysis results including categories from various security services. Not all services will have categories for all domains.

virustotal_cat(domains = NULL, apikey = NULL)

Arguments

domains

domain names as character vector

apikey

virustotal API key

Value

data.frame with domain and VirusTotal analysis results

Details

Get the API Access Key from https://www.virustotal.com/. Either pass the API Key to the function # nolint: line_length_linter. or set the environmental variable: VirustotalToken. Environment variables persist within a R session.

Examples

if (FALSE) { # \dontrun{
virustotal_cat("http://www.google.com")
virustotal_cat(c("google.com", "facebook.com"))
} # }