| claude_cat | R Documentation |
Fetches category of content hosted by a domain using Anthropic's Claude API. The function uses Claude models to classify domains into specified categories.
claude_cat(
domains = NULL,
api_key = NULL,
categories = NULL,
model = "claude-3-haiku-20240307",
rate_limit = 0.5
)
domains |
vector of domain names |
api_key |
Anthropic API key. If not provided, looks for ANTHROPIC_API_KEY or CLAUDE_API_KEY environment variable |
categories |
vector of categories to classify into. If NULL, uses default web categories |
model |
Claude model to use (default: "claude-3-haiku-20240307" for cost efficiency) |
rate_limit |
delay in seconds between API calls (default: 0.5) |
data.frame with original list and content category of the domain
## Not run:
claude_cat("google.com")
claude_cat(c("google.com", "facebook.com"))
claude_cat("google.com", categories = c("search", "social", "ecommerce", "news", "other"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.