View source: R/get_dmoz_data.R
| get_dmoz_data | R Documentation |
Downloads archived DMOZ (Open Directory Project) data. DMOZ was discontinued in March 2017. This function downloads our preserved copy of the final DMOZ dataset. For more details, check: https://github.com/themains/rdomains/tree/master/data-raw/dmoz/
get_dmoz_data(outdir = ".", overwrite = FALSE)
outdir |
Optional; folder to which you want to save the file; Default is same folder |
overwrite |
Optional; default is FALSE. If TRUE, the file is overwritten. |
https://archive.org/details/dmoz-rdf-20150327
## Not run:
get_dmoz_data()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.