powered by
Downloads archived DMOZ (Open Directory Project) data. DMOZ was discontinued in March 2017. This function downloads our preserved copy of the final DMOZ dataset. For more details, check: https://github.com/themains/rdomains/tree/master/data-raw/dmoz/
get_dmoz_data(outdir = ".", overwrite = FALSE)
Optional; folder to which you want to save the file; Default is same folder
Optional; default is FALSE. If TRUE, the file is overwritten.
https://archive.org/details/dmoz-rdf-20150327
if (FALSE) { get_dmoz_data() }
Run the code above in your browser using DataLab