View source: R/get_shalla_data.R
| get_shalla_data | R Documentation |
Shallalist service was discontinued in January 2022. This function downloads
the last archived copy (from 1/14/22) that we have preserved on GitHub.
The original service at shallalist.de is no longer available.
Downloads, unzips and saves the final version of shallalist data. By default, saves shalla data
as shalla_domain_category.csv.
get_shalla_data(outdir = "./", overwrite = FALSE)
outdir |
Optional; folder to which you want to save the file; Default is same folder |
overwrite |
Optional; default is FALSE. If TRUE, the file is overwritten. |
https://web.archive.org/web/20210502020725/http://www.shallalist.de/
## Not run:
get_shalla_data()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.