Shallalist service was discontinued in January 2022. This function downloads
the last archived copy (from 1/14/22) that we have preserved on GitHub.
The original service at shallalist.de is no longer available.
Downloads, unzips and saves the final version of shallalist data. By default, saves shalla data
as shalla_domain_category.csv.
Usage
get_shalla_data(outdir = "./", overwrite = FALSE)
Arguments
outdir
Optional; folder to which you want to save the file; Default is same folder
overwrite
Optional; default is FALSE. If TRUE, the file is overwritten.