View source: R/get_stevenblack_data.R
| get_stevenblack_data | R Documentation |
Downloads the latest version of Steven Black's unified hosts file. The hosts file contains domains known for serving ads, malware, and tracking.
get_stevenblack_data(outdir = "./", variant = "base", overwrite = FALSE)
outdir |
Optional; folder to which you want to save the file; Default is current directory |
variant |
Optional; which variant to download. Options: "base", "porn", "social", "gambling", "all" |
overwrite |
Optional; default is FALSE. If TRUE, the file is overwritten. |
https://github.com/StevenBlack/hosts
## Not run:
get_stevenblack_data()
get_stevenblack_data(variant = "all")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.