Learn R Programming

rdomains (version 0.5.0)

get_stevenblack_data: Get Steven Black's Host List Data

Description

Downloads the latest version of Steven Black's unified hosts file. The hosts file contains domains known for serving ads, malware, and tracking.

Usage

get_stevenblack_data(outdir = "./", variant = "base", overwrite = FALSE)

Arguments

outdir

Optional; folder to which you want to save the file; Default is current directory

variant

Optional; which variant to download. Options: "base", "porn", "social", "gambling", "all"

overwrite

Optional; default is FALSE. If TRUE, the file is overwritten.

References

https://github.com/StevenBlack/hosts

Examples

Run this code
if (FALSE) {
get_stevenblack_data()
get_stevenblack_data(variant = "all")
}

Run the code above in your browser using DataLab