powered by
Downloads the latest version of Steven Black's unified hosts file. The hosts file contains domains known for serving ads, malware, and tracking.
get_stevenblack_data(outdir = "./", variant = "base", overwrite = FALSE)
Optional; folder to which you want to save the file; Default is current directory
Optional; which variant to download. Options: "base", "porn", "social", "gambling", "all"
Optional; default is FALSE. If TRUE, the file is overwritten.
https://github.com/StevenBlack/hosts
if (FALSE) { get_stevenblack_data() get_stevenblack_data(variant = "all") }
Run the code above in your browser using DataLab