Learn R Programming

rdomains (version 0.5.0)

rdomains-package: rdomains: Classify Domains by their Content

Description

Want to know what kind of content is carried on a domain? Get the results quickly using rdomains. The package provides access to virustotal API, shalla, aws, OpenAI GPT models, Anthropic Claude models, and validated ML model based off shallalist data to predict content of a domain.

Arguments

Author

Gaurav Sood

Details

To learn how to use rdomains, see this vignette: ../doc/rdomains.html.