Want to know what kind of content is carried on a domain?
Get the results quickly using rdomains. The package provides access to virustotal
API, shalla, aws, OpenAI GPT models, Anthropic Claude models,
and validated ML model based off shallalist data to predict content of a domain.