View source: R/stevenblack_cat.R
| stevenblack_cat | R Documentation |
Classifies domains based on Steven Black's unified host list which blocks ads, malware, and tracking domains. The function checks if a domain appears in the blocklist and categorizes it accordingly.
stevenblack_cat(domain = NULL, use_file = NULL)
domain |
domain names as character vector |
use_file |
path to a local Steven Black hosts file. If NULL, downloads from GitHub |
Steven Black's host list is a consolidated list from multiple sources including adaway.org, mvps.org, malwaredomainlist.com, and someonewhocares.org.
data.frame with original domain name and category
https://github.com/StevenBlack/hosts
## Not run:
stevenblack_cat("doubleclick.net")
stevenblack_cat(c("google.com", "googleadservices.com", "malware-example.com"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.