virustotal_cat: Get Category from VirusTotal

View source: R/virustotal_cat.R

virustotal_catR Documentation

Get Category from VirusTotal

Description

Returns category of content from multiple security vendors using the VirusTotal API v3. The function retrieves domain analysis results including categories from various security services. Not all services will have categories for all domains.

Usage

virustotal_cat(domains = NULL, apikey = NULL)

Arguments

domains

domain names as character vector

apikey

virustotal API key

Details

Get the API Access Key from https://www.virustotal.com/. Either pass the API Key to the function or set the environmental variable: VirustotalToken. Environment variables persist within a R session.

Value

data.frame with domain and VirusTotal analysis results

References

https://docs.virustotal.com/reference/domains

Examples

## Not run: 
virustotal_cat("http://www.google.com")
virustotal_cat(c("google.com", "facebook.com"))

## End(Not run)

rdomains documentation built on May 14, 2026, 9:07 a.m.