View source: R/virustotal_cat.R
| virustotal_cat | R Documentation |
Returns category of content from multiple security vendors using the VirusTotal API v3. The function retrieves domain analysis results including categories from various security services. Not all services will have categories for all domains.
virustotal_cat(domains = NULL, apikey = NULL)
domains |
domain names as character vector |
apikey |
virustotal API key |
Get the API Access Key from https://www.virustotal.com/. Either pass the API Key to the function
or set the environmental variable: VirustotalToken. Environment variables persist within
a R session.
data.frame with domain and VirusTotal analysis results
https://docs.virustotal.com/reference/domains
## Not run:
virustotal_cat("http://www.google.com")
virustotal_cat(c("google.com", "facebook.com"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.