Learn R Programming

rdomains (version 0.5.0)

virustotal_cat: Get Category from VirusTotal

Description

Returns category of content from multiple security vendors using the VirusTotal API v3. The function retrieves domain analysis results including categories from various security services. Not all services will have categories for all domains.

Usage

virustotal_cat(domains = NULL, apikey = NULL)

Value

data.frame with domain and VirusTotal analysis results

Arguments

domains

domain names as character vector

apikey

virustotal API key

Details

Get the API Access Key from https://www.virustotal.com/. Either pass the API Key to the function or set the environmental variable: VirustotalToken. Environment variables persist within a R session.

References

https://docs.virustotal.com/reference/domains

Examples

Run this code
if (FALSE) {
virustotal_cat("http://www.google.com")
virustotal_cat(c("google.com", "facebook.com"))
}

Run the code above in your browser using DataLab